@@ -32,7 +32,7 @@
 #include <stdbool.h>
 #include <time.h>
 
-#include "error.h"
+#include "die.h"
 #include "minmax.h"
 #include "linebuffer.h"
 #include "system.h"
@@ -65,6 +65,8 @@ struct operation_data operations[] =
   {NUMERIC_SCALAR, AUTO_SET_FIRST, NUMERIC_RESULT},
   /* OP_ABSMAX */
   {NUMERIC_SCALAR, AUTO_SET_FIRST, NUMERIC_RESULT},
+  /* OP_RANGE */
+  {NUMERIC_SCALAR, IGNORE_FIRST, NUMERIC_RESULT},
   /* OP_FIRST */
   {STRING_SCALAR,  IGNORE_FIRST, STRING_RESULT},
   /* OP_LAST */
@@ -81,6 +83,8 @@ struct operation_data operations[] =
   {NUMERIC_VECTOR, IGNORE_FIRST, NUMERIC_RESULT},
   /* OP_IQR */
   {NUMERIC_VECTOR, IGNORE_FIRST, NUMERIC_RESULT},
+  /* OP_PERCENTILE */
+  {NUMERIC_VECTOR, IGNORE_FIRST, NUMERIC_RESULT},
   /* OP_PSTDEV */
   {NUMERIC_VECTOR, IGNORE_FIRST, NUMERIC_RESULT},
   /* OP_SSTDEV */
@@ -316,7 +320,7 @@ verify_slave_num_values (const struct fieldop *op)
   assert (op && !op->slave && op->slave_op);     /* LCOV_EXCL_LINE */
 
   if (op->num_values != op->slave_op->num_values)
-    error (EXIT_FAILURE, 0, _("input error for operation %s: \
+    die (EXIT_FAILURE, 0, _("input error for operation %s: \
 fields %"PRIuMAX",%"PRIuMAX" have different number of items"),
                             quote (get_field_operation_name (op->op)),
                             (uintmax_t)op->slave_op->field,
@@ -348,7 +352,7 @@ field_op_collect (struct fieldop *op,
          and returns invalid value.
          Make a copy of the input buffer and NULL-terminate it */
       if (slen >= sizeof (tmpbuf))
-        error (EXIT_FAILURE, 0,
+        die (EXIT_FAILURE, 0,
                 "internal error: input field too long (%zu)", slen);
       memcpy (tmpbuf,str,slen);
       tmpbuf[slen]=0;
@@ -412,6 +416,24 @@ field_op_collect (struct fieldop *op,
         }
       break;
 
+    case OP_RANGE:
+      /* Upon the first value, we store it twice
+         (once for min, once for max).
+         For subsequence values, we update the min/max entries directly. */
+      if (op->first)
+        {
+          field_op_add_value (op, num_value);
+          field_op_add_value (op, num_value);
+        }
+      else
+        {
+          if (num_value < op->values[0])
+            op->values[0] = num_value;
+          if (num_value > op->values[1])
+            op->values[1] = num_value;
+        }
+      break;
+
     case OP_FIRST:
       if (op->first)
         {
@@ -465,6 +487,7 @@ field_op_collect (struct fieldop *op,
     case OP_QUARTILE_1:
     case OP_QUARTILE_3:
     case OP_IQR:
+    case OP_PERCENTILE:
     case OP_PSTDEV:
     case OP_SSTDEV:
     case OP_PVARIANCE:
@@ -531,8 +554,8 @@ field_op_collect (struct fieldop *op,
       };
       break;
 
-    case OP_INVALID:
-    default:
+    case OP_INVALID:                 /* LCOV_EXCL_LINE */
+    default:                         /* LCOV_EXCL_LINE */
       /* Should never happen */
       internal_error ("bad op");     /* LCOV_EXCL_LINE */
     }
@@ -648,6 +671,7 @@ field_op_summarize_empty (struct fieldop *op)
     case OP_QUARTILE_1:
     case OP_QUARTILE_3:
     case OP_IQR:
+    case OP_PERCENTILE:
     case OP_MAD:
     case OP_MADRAW:
     case OP_PSTDEV:
@@ -667,6 +691,7 @@ field_op_summarize_empty (struct fieldop *op)
     case OP_ROUND:
     case OP_TRUNCATE:
     case OP_FRACTION:
+    case OP_RANGE:
       numeric_result = nanl ("");
       break;
 
@@ -705,8 +730,8 @@ field_op_summarize_empty (struct fieldop *op)
       strcpy (op->out_buf, "");
       break;
 
-    case OP_INVALID:
-    default:
+    case OP_INVALID:                 /* LCOV_EXCL_LINE */
+    default:                         /* LCOV_EXCL_LINE */
       /* Should never happen */
       internal_error ("bad op");     /* LCOV_EXCL_LINE */
     }
@@ -766,6 +791,10 @@ field_op_summarize (struct fieldop *op)
       memcpy (op->out_buf, op->str_buf, op->str_buf_used);
       break;
 
+    case OP_RANGE:
+      numeric_result = op->values[1] - op->values[0];
+      break;
+
     case OP_MEDIAN:
       field_op_sort_values (op);
       numeric_result = median_value ( op->values, op->num_values );
@@ -787,6 +816,12 @@ field_op_summarize (struct fieldop *op)
                        - quartile1_value ( op->values, op->num_values );
       break;
 
+    case OP_PERCENTILE:
+      field_op_sort_values (op);
+      numeric_result = percentile_value ( op->values, op->num_values,
+                                          op->params.percentile / 100.0 );
+      break;
+
     case OP_PSTDEV:
       numeric_result = stdev_value ( op->values, op->num_values, DF_POPULATION);
       break;
@@ -917,8 +952,8 @@ field_op_summarize (struct fieldop *op)
       field_op_to_hex (op, tmpbuf, 64);
       break;
 
-    case OP_INVALID:
-    default:
+    case OP_INVALID:                 /* LCOV_EXCL_LINE */
+    default:                         /* LCOV_EXCL_LINE */
       /* Should never happen */
       internal_error ("bad op");     /* LCOV_EXCL_LINE */
     }
@@ -999,9 +1034,9 @@ field_op_collect_result_name (const enum FIELD_OP_COLLECT_RESULT flocr)
      return _("invalid numeric value");
    case FLOCR_INVALID_BASE64:
      return _("invalid base64 value");
-   case FLOCR_OK:
-   case FLOCR_OK_KEEP_LINE:
-   case FLOCR_OK_SKIPPED:
+   case FLOCR_OK:                                /* LCOV_EXCL_LINE */
+   case FLOCR_OK_KEEP_LINE:                      /* LCOV_EXCL_LINE */
+   case FLOCR_OK_SKIPPED:                        /* LCOV_EXCL_LINE */
    default:
      internal_error ("op_collect_result_name");  /* LCOV_EXCL_LINE */
      return "";                                  /* LCOV_EXCL_LINE */
